/**
 * Wysebee PublicationManifest is based on pub manifest
 * https://www.w3.org/TR/pub-manifest/#webidl-wpm
 * along with some customization for convenience purpose
 */
export declare enum TextDirection {
    LTR = "ltr",
    RTL = "rtl"
}
export declare type LocalizableString = {
    value: string;
    language?: string;
    direction?: TextDirection;
};
export declare type LinkedResource = {
    url: string;
    encodingFormat?: string;
    name?: LocalizableString[];
    description?: LocalizableString[];
    rel?: string[];
    integrity?: string;
    duration?: string;
    alternate?: LinkedResource[];
};
export declare type Entity = {
    type?: string[];
    name: LocalizableString[];
    id?: string;
    url?: string;
    identifier?: string[];
};
export declare type PublicationManifest = {
    profile: string;
    id: string;
    name: string;
    readingOrder: string[];
    type?: string[];
    conformsTo?: string[];
    abridged?: boolean;
    accessMode?: string[];
    accessModeSufficient?: string[];
    accessibilityFeature?: string[];
    accessibilityHazard?: string[];
    accessibilitySummary?: LocalizableString[];
    artist?: Entity[];
    author?: Entity[] | string;
    colorist?: Entity[];
    contributor?: Entity[];
    creator?: Entity[];
    editor?: Entity[];
    illustrator?: Entity[];
    inker?: Entity[];
    letterer?: Entity[];
    penciler?: Entity[];
    publisher?: Entity[];
    readBy?: Entity[];
    translator?: Entity[];
    url?: string[];
    duration?: string[];
    inLanguage?: string[];
    dateModified?: string;
    datePublished?: string;
    readingProgression?: TextDirection;
    resources?: LinkedResource[];
    links?: LinkedResource[];
    uniqueResources?: string;
    coverImage?: string;
    toc?: string;
    description?: string;
};
